@@ -1,5 +1,5 @@
 /* Copyright Contributors to the Open Cluster Management project */
-import { Http2ServerRequest, Http2ServerResponse } from 'http2'
+import { constants, Http2ServerRequest, Http2ServerResponse, OutgoingHttpHeaders } from 'http2'
 import { request, RequestOptions } from 'https'
 import { pipeline } from 'stream'
 import { URL } from 'url'
@@ -7,13 +7,25 @@ import { parseCookies } from '../lib/cookies'
 import { logger } from '../lib/logger'
 import { notFound, unauthorized } from '../lib/respond'
 
+const proxyHeaders = [
+    constants.HTTP2_HEADER_ACCEPT,
+    constants.HTTP2_HEADER_ACCEPT_ENCODING,
+    constants.HTTP2_HEADER_CONTENT_ENCODING,
+    constants.HTTP2_HEADER_CONTENT_LENGTH,
+    constants.HTTP2_HEADER_CONTENT_TYPE,
+]
+
 export function search(req: Http2ServerRequest, res: Http2ServerResponse): void {
     const token = parseCookies(req)['acm-access-token-cookie']
     if (!token) return unauthorized(req, res)
 
+    const headers: OutgoingHttpHeaders = { authorization: `Bearer ${token}` }
+    for (const header of proxyHeaders) {
+        if (req.headers[header]) headers[header] = req.headers[header]
+    }
+
     const searchUrl = process.env.SEARCH_API_URL || 'https://search-search-api:4010'
     const url = new URL(searchUrl + '/searchapi/graphql')
-    const headers = req.headers
     headers.authorization = `Bearer ${token}`
     headers.host = url.hostname
     const options: RequestOptions = {
