@@ -2,7 +2,7 @@
 
 import { makeStyles } from '@material-ui/styles'
 import { PolicyReport, PolicyReportResults } from '../../../../../resources'
-import { AcmLabels, AcmTable, compareStrings } from '@open-cluster-management/ui-components'
+import { AcmLabels, AcmTable, compareStrings } from '@stolostron/ui-components'
 import { ChartDonut, ChartLabel, ChartLegend } from '@patternfly/react-charts'
 import {
     Button,
