@@ -1234,8 +1234,7 @@ module.exports = {
 		"12.0.16",
 		"12.0.17",
 		"12.0.18",
-		"12.1.0",
-		"12.1.1"
+		"12.1.0"
 	],
 	"90.0.4402.0": [
 		"13.0.0-beta.2",
@@ -1362,8 +1361,7 @@ module.exports = {
 		"13.2.1",
 		"13.2.2",
 		"13.2.3",
-		"13.3.0",
-		"13.4.0"
+		"13.3.0"
 	],
 	"92.0.4511.0": [
 		"14.0.0-beta.1",
@@ -1470,9 +1468,6 @@ module.exports = {
 	"93.0.4577.58": [
 		"14.0.0"
 	],
-	"93.0.4577.63": [
-		"14.0.1"
-	],
 	"94.0.4584.0": [
 		"15.0.0-alpha.3",
 		"15.0.0-alpha.4",
@@ -1508,15 +1503,7 @@ module.exports = {
 		"15.0.0-alpha.10"
 	],
 	"94.0.4606.20": [
-		"15.0.0-beta.1",
-		"15.0.0-beta.2"
-	],
-	"94.0.4606.31": [
-		"15.0.0-beta.3",
-		"15.0.0-beta.4",
-		"15.0.0-beta.5",
-		"15.0.0-beta.6",
-		"15.0.0-beta.7"
+		"15.0.0-beta.1"
 	],
 	"93.0.4530.0": [
 		"15.0.0-nightly.20210603",
@@ -1546,21 +1533,6 @@ module.exports = {
 		"16.0.0-nightly.20210826",
 		"16.0.0-nightly.20210827",
 		"16.0.0-nightly.20210830",
-		"16.0.0-nightly.20210831",
-		"16.0.0-nightly.20210901"
-	],
-	"95.0.4629.0": [
-		"16.0.0-nightly.20210902",
-		"16.0.0-nightly.20210903",
-		"16.0.0-nightly.20210906",
-		"16.0.0-nightly.20210907",
-		"16.0.0-nightly.20210908",
-		"16.0.0-nightly.20210909",
-		"16.0.0-nightly.20210910",
-		"16.0.0-nightly.20210913",
-		"16.0.0-nightly.20210914",
-		"16.0.0-nightly.20210915",
-		"16.0.0-nightly.20210916",
-		"16.0.0-nightly.20210917"
+		"16.0.0-nightly.20210831"
 	]
 };
\ No newline at end of file
