@@ -871,6 +871,7 @@ module.exports = {
 	"12.2.0": "89.0.4389.128",
 	"12.2.1": "89.0.4389.128",
 	"12.2.2": "89.0.4389.128",
+	"12.2.3": "89.0.4389.128",
 	"13.0.0-beta.2": "90.0.4402.0",
 	"13.0.0-beta.3": "90.0.4402.0",
 	"13.0.0-beta.4": "90.0.4415.0",
@@ -968,6 +969,12 @@ module.exports = {
 	"13.5.2": "91.0.4472.164",
 	"13.6.0": "91.0.4472.164",
 	"13.6.1": "91.0.4472.164",
+	"13.6.2": "91.0.4472.164",
+	"13.6.3": "91.0.4472.164",
+	"13.6.6": "91.0.4472.164",
+	"13.6.7": "91.0.4472.164",
+	"13.6.8": "91.0.4472.164",
+	"13.6.9": "91.0.4472.164",
 	"14.0.0-beta.1": "92.0.4511.0",
 	"14.0.0-beta.2": "92.0.4511.0",
 	"14.0.0-beta.3": "92.0.4511.0",
@@ -1040,6 +1047,12 @@ module.exports = {
 	"14.1.0": "93.0.4577.82",
 	"14.1.1": "93.0.4577.82",
 	"14.2.0": "93.0.4577.82",
+	"14.2.1": "93.0.4577.82",
+	"14.2.2": "93.0.4577.82",
+	"14.2.3": "93.0.4577.82",
+	"14.2.4": "93.0.4577.82",
+	"14.2.5": "93.0.4577.82",
+	"14.2.6": "93.0.4577.82",
 	"15.0.0-alpha.1": "93.0.4566.0",
 	"15.0.0-alpha.2": "93.0.4566.0",
 	"15.0.0-alpha.3": "94.0.4584.0",
@@ -1102,6 +1115,14 @@ module.exports = {
 	"15.1.2": "94.0.4606.71",
 	"15.2.0": "94.0.4606.81",
 	"15.3.0": "94.0.4606.81",
+	"15.3.1": "94.0.4606.81",
+	"15.3.2": "94.0.4606.81",
+	"15.3.3": "94.0.4606.81",
+	"15.3.4": "94.0.4606.81",
+	"15.3.5": "94.0.4606.81",
+	"15.3.6": "94.0.4606.81",
+	"15.3.7": "94.0.4606.81",
+	"15.4.0": "94.0.4606.81",
 	"16.0.0-alpha.1": "95.0.4629.0",
 	"16.0.0-alpha.2": "95.0.4629.0",
 	"16.0.0-alpha.3": "95.0.4629.0",
@@ -1116,6 +1137,10 @@ module.exports = {
 	"16.0.0-beta.3": "96.0.4647.0",
 	"16.0.0-beta.4": "96.0.4664.18",
 	"16.0.0-beta.5": "96.0.4664.18",
+	"16.0.0-beta.6": "96.0.4664.27",
+	"16.0.0-beta.7": "96.0.4664.27",
+	"16.0.0-beta.8": "96.0.4664.35",
+	"16.0.0-beta.9": "96.0.4664.35",
 	"16.0.0-nightly.20210722": "93.0.4566.0",
 	"16.0.0-nightly.20210723": "93.0.4566.0",
 	"16.0.0-nightly.20210726": "93.0.4566.0",
@@ -1161,6 +1186,32 @@ module.exports = {
 	"16.0.0-nightly.20210920": "95.0.4629.0",
 	"16.0.0-nightly.20210921": "95.0.4629.0",
 	"16.0.0-nightly.20210922": "95.0.4629.0",
+	"16.0.0": "96.0.4664.45",
+	"16.0.1": "96.0.4664.45",
+	"16.0.2": "96.0.4664.55",
+	"16.0.3": "96.0.4664.55",
+	"16.0.4": "96.0.4664.55",
+	"16.0.5": "96.0.4664.55",
+	"16.0.6": "96.0.4664.110",
+	"16.0.7": "96.0.4664.110",
+	"16.0.8": "96.0.4664.110",
+	"16.0.9": "96.0.4664.174",
+	"16.0.10": "96.0.4664.174",
+	"17.0.0-alpha.1": "96.0.4664.4",
+	"17.0.0-alpha.2": "96.0.4664.4",
+	"17.0.0-alpha.3": "96.0.4664.4",
+	"17.0.0-alpha.4": "98.0.4706.0",
+	"17.0.0-alpha.5": "98.0.4706.0",
+	"17.0.0-alpha.6": "98.0.4706.0",
+	"17.0.0-beta.1": "98.0.4706.0",
+	"17.0.0-beta.2": "98.0.4706.0",
+	"17.0.0-beta.3": "98.0.4758.9",
+	"17.0.0-beta.4": "98.0.4758.11",
+	"17.0.0-beta.5": "98.0.4758.11",
+	"17.0.0-beta.6": "98.0.4758.11",
+	"17.0.0-beta.7": "98.0.4758.11",
+	"17.0.0-beta.8": "98.0.4758.11",
+	"17.0.0-beta.9": "98.0.4758.11",
 	"17.0.0-nightly.20210923": "95.0.4629.0",
 	"17.0.0-nightly.20210924": "95.0.4629.0",
 	"17.0.0-nightly.20210927": "95.0.4629.0",
@@ -1186,5 +1237,82 @@ module.exports = {
 	"17.0.0-nightly.20211025": "96.0.4664.4",
 	"17.0.0-nightly.20211026": "96.0.4664.4",
 	"17.0.0-nightly.20211027": "96.0.4664.4",
-	"17.0.0-nightly.20211028": "96.0.4664.4"
+	"17.0.0-nightly.20211028": "96.0.4664.4",
+	"17.0.0-nightly.20211029": "96.0.4664.4",
+	"17.0.0-nightly.20211101": "96.0.4664.4",
+	"17.0.0-nightly.20211102": "96.0.4664.4",
+	"17.0.0-nightly.20211103": "96.0.4664.4",
+	"17.0.0-nightly.20211104": "96.0.4664.4",
+	"17.0.0-nightly.20211105": "96.0.4664.4",
+	"17.0.0-nightly.20211108": "96.0.4664.4",
+	"17.0.0-nightly.20211109": "96.0.4664.4",
+	"17.0.0-nightly.20211110": "96.0.4664.4",
+	"17.0.0-nightly.20211111": "96.0.4664.4",
+	"17.0.0-nightly.20211112": "96.0.4664.4",
+	"17.0.0-nightly.20211115": "96.0.4664.4",
+	"17.0.0-nightly.20211116": "96.0.4664.4",
+	"17.0.0-nightly.20211117": "96.0.4664.4",
+	"17.0.0": "98.0.4758.74",
+	"17.0.1": "98.0.4758.82",
+	"17.1.0": "98.0.4758.102",
+	"18.0.0-alpha.1": "99.0.4767.0",
+	"18.0.0-alpha.2": "99.0.4767.0",
+	"18.0.0-alpha.3": "99.0.4767.0",
+	"18.0.0-alpha.4": "99.0.4767.0",
+	"18.0.0-alpha.5": "99.0.4767.0",
+	"18.0.0-nightly.20211118": "96.0.4664.4",
+	"18.0.0-nightly.20211119": "96.0.4664.4",
+	"18.0.0-nightly.20211122": "96.0.4664.4",
+	"18.0.0-nightly.20211123": "96.0.4664.4",
+	"18.0.0-nightly.20211124": "98.0.4706.0",
+	"18.0.0-nightly.20211125": "98.0.4706.0",
+	"18.0.0-nightly.20211126": "98.0.4706.0",
+	"18.0.0-nightly.20211129": "98.0.4706.0",
+	"18.0.0-nightly.20211130": "98.0.4706.0",
+	"18.0.0-nightly.20211201": "98.0.4706.0",
+	"18.0.0-nightly.20211202": "98.0.4706.0",
+	"18.0.0-nightly.20211203": "98.0.4706.0",
+	"18.0.0-nightly.20211206": "98.0.4706.0",
+	"18.0.0-nightly.20211207": "98.0.4706.0",
+	"18.0.0-nightly.20211208": "98.0.4706.0",
+	"18.0.0-nightly.20211209": "98.0.4706.0",
+	"18.0.0-nightly.20211210": "98.0.4706.0",
+	"18.0.0-nightly.20211213": "98.0.4706.0",
+	"18.0.0-nightly.20211214": "98.0.4706.0",
+	"18.0.0-nightly.20211215": "98.0.4706.0",
+	"18.0.0-nightly.20211216": "98.0.4706.0",
+	"18.0.0-nightly.20211217": "98.0.4706.0",
+	"18.0.0-nightly.20211220": "98.0.4706.0",
+	"18.0.0-nightly.20211221": "98.0.4706.0",
+	"18.0.0-nightly.20211222": "98.0.4706.0",
+	"18.0.0-nightly.20211223": "98.0.4706.0",
+	"18.0.0-nightly.20211228": "98.0.4706.0",
+	"18.0.0-nightly.20211229": "98.0.4706.0",
+	"18.0.0-nightly.20211231": "98.0.4706.0",
+	"18.0.0-nightly.20220103": "98.0.4706.0",
+	"18.0.0-nightly.20220104": "98.0.4706.0",
+	"18.0.0-nightly.20220105": "98.0.4706.0",
+	"18.0.0-nightly.20220106": "98.0.4706.0",
+	"18.0.0-nightly.20220107": "98.0.4706.0",
+	"18.0.0-nightly.20220110": "98.0.4706.0",
+	"18.0.0-nightly.20220111": "99.0.4767.0",
+	"18.0.0-nightly.20220112": "99.0.4767.0",
+	"18.0.0-nightly.20220113": "99.0.4767.0",
+	"18.0.0-nightly.20220114": "99.0.4767.0",
+	"18.0.0-nightly.20220117": "99.0.4767.0",
+	"18.0.0-nightly.20220118": "99.0.4767.0",
+	"18.0.0-nightly.20220119": "99.0.4767.0",
+	"18.0.0-nightly.20220121": "99.0.4767.0",
+	"18.0.0-nightly.20220124": "99.0.4767.0",
+	"18.0.0-nightly.20220125": "99.0.4767.0",
+	"18.0.0-nightly.20220127": "99.0.4767.0",
+	"18.0.0-nightly.20220128": "99.0.4767.0",
+	"18.0.0-nightly.20220131": "99.0.4767.0",
+	"18.0.0-nightly.20220201": "99.0.4767.0",
+	"19.0.0-nightly.20220202": "99.0.4767.0",
+	"19.0.0-nightly.20220203": "99.0.4767.0",
+	"19.0.0-nightly.20220204": "99.0.4767.0",
+	"19.0.0-nightly.20220207": "99.0.4767.0",
+	"19.0.0-nightly.20220208": "99.0.4767.0",
+	"19.0.0-nightly.20220209": "99.0.4767.0"
 };
\ No newline at end of file
