@@ -781,8 +781,6 @@ AST_Toplevel.DEFMETHOD("mangle_names", function(options) {
     }
 
     const mangled_names = this.mangled_names = new Set();
-    unmangleable_names = new Set();
-
     if (options.cache) {
         this.globals.forEach(collect);
         if (options.cache.props) {
@@ -835,6 +833,7 @@ AST_Toplevel.DEFMETHOD("mangle_names", function(options) {
     this.walk(tw);
 
     if (options.keep_fnames || options.keep_classnames) {
+        unmangleable_names = new Set();
         // Collect a set of short names which are unmangleable,
         // for use in avoiding collisions in next_mangled.
         to_mangle.forEach(def => {
@@ -850,9 +849,9 @@ AST_Toplevel.DEFMETHOD("mangle_names", function(options) {
     unmangleable_names = null;
 
     function collect(symbol) {
-        if (symbol.export & MASK_EXPORT_DONT_MANGLE) {
-            unmangleable_names.add(symbol.name);
-        } else if (!options.reserved.has(symbol.name)) {
+        const should_mangle = !options.reserved.has(symbol.name)
+            && !(symbol.export & MASK_EXPORT_DONT_MANGLE);
+        if (should_mangle) {
             to_mangle.push(symbol);
         }
     }
