@@ -1,6 +1,9 @@
 import * as React from 'react';
 import hoistNonReactStatics from 'hoist-non-react-statics';
 
+/* eslint-disable camelcase */
+import chart_legend_Margin from '@patternfly/react-tokens/dist/esm/chart_legend_Margin';
+
 import {
   AnimatePropTypeInterface,
   D3Scale,
@@ -336,6 +339,11 @@ export interface ChartProps extends VictoryChartProps {
    * @hide
    */
   sharedEvents?: { events: any[]; getEventState: Function };
+  /**
+   * Convenience prop to hide both x and y axis, which are shown by default. Alternatively, the axis can be hidden via
+   * chart styles.
+   */
+  showAxis?: boolean;
   /**
    * By default domainPadding is coerced to existing quadrants. This means that if a given domain only includes positive
    * values, no amount of padding applied by domainPadding will result in a domain with negative values. This is the
@@ -420,6 +428,7 @@ export const Chart: React.FunctionComponent<ChartProps> = ({
   legendData,
   legendPosition = ChartCommonStyles.legend.position as ChartLegendPosition,
   padding,
+  showAxis = true,
   themeColor,
   themeVariant,
 
@@ -478,6 +487,12 @@ export const Chart: React.FunctionComponent<ChartProps> = ({
       dy += xAxisLabelHeight + legendTitleHeight;
       dx = -10;
     }
+
+    // Adjust legend position when axis is hidden
+    if (!showAxis) {
+      dy -= chart_legend_Margin.value;
+    }
+
     return getComputedLegend({
       allowWrap: legendAllowWrap,
       chartType: 'chart',
@@ -492,8 +507,15 @@ export const Chart: React.FunctionComponent<ChartProps> = ({
     });
   };
 
-  // Note: containerComponent is required for theme
   const VictoryChartWithContainerComponent = VictoryChart as any;
+
+  if (!showAxis) {
+    const Null = (): any => null;
+    VictoryChartWithContainerComponent.defaultProps.defaultAxes.dependent = <Null />;
+    VictoryChartWithContainerComponent.defaultProps.defaultAxes.independent = <Null />;
+  }
+
+  // Note: containerComponent is required for theme
   return (
     <VictoryChartWithContainerComponent
       containerComponent={container}
